[SCM] Samba Shared Repository - branch v3-2-test updated - initial-v3-2-unstable-919-ge86d027

Jeremy Allison jra at samba.org
Thu Dec 27 18:30:55 GMT 2007


The branch, v3-2-test has been updated
       via  e86d027823c85173c64e7b85406e98f6f7345b10 (commit)
      from  d67b2634068be9c69082a2b8c22c831aba371cd9 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-2-test


- Log -----------------------------------------------------------------
commit e86d027823c85173c64e7b85406e98f6f7345b10
Author: Jeremy Allison <jra at samba.org>
Date:   Thu Dec 27 10:18:22 2007 -0800

    Add CIFS_UNIX_TRANSPORT_ENCRYPTION_CAP capability to
    our reported caps.
    Jeremy.

-----------------------------------------------------------------------

Summary of changes:
 source/include/trans2.h |    3 ++-
 source/smbd/trans2.c    |    6 +++++-
 2 files changed, 7 insertions(+), 2 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source/include/trans2.h b/source/include/trans2.h
index 8ed075d..3759d59 100644
--- a/source/include/trans2.h
+++ b/source/include/trans2.h
@@ -530,7 +530,8 @@ findfirst/findnext is SMB_FIND_FILE_UNIX_INFO2.
 #define CIFS_UNIX_POSIX_PATH_OPERATIONS_CAP	   0x20 /* We can cope with POSIX open/mkdir/unlink etc. */
 #define CIFS_UNIX_LARGE_READ_CAP           0x40 /* We can cope with 24 bit reads in readX. */
 #define CIFS_UNIX_LARGE_WRITE_CAP          0x80 /* We can cope with 24 bit writes in writeX. */
-
+#define CIFS_UNIX_TRANSPORT_ENCRYPTION_CAP      0x100 /* We can do SPNEGO negotiations for encryption. */
+#define CIFS_UNIX_TRANSPORT_ENCRYPTION_MANDATORY_CAP    0x200 /* We *must* SPNEGO negotiations for encryption. */
 
 #define SMB_QUERY_POSIX_FS_INFO     0x201
 
diff --git a/source/smbd/trans2.c b/source/smbd/trans2.c
index 0e34284..5a8fe41 100644
--- a/source/smbd/trans2.c
+++ b/source/smbd/trans2.c
@@ -2737,7 +2737,10 @@ cBytesSector=%u, cUnitTotal=%u, cUnitAvail=%d\n", (unsigned int)bsize, (unsigned
 			data_len = 12;
 			SSVAL(pdata,0,CIFS_UNIX_MAJOR_VERSION);
 			SSVAL(pdata,2,CIFS_UNIX_MINOR_VERSION);
-			/* We have POSIX ACLs, pathname and locking capability. */
+
+			/* We have POSIX ACLs, pathname, encryption, 
+			 * large read/write, and locking capability. */
+
 			SBIG_UINT(pdata,4,((SMB_BIG_UINT)(
 					CIFS_UNIX_POSIX_ACLS_CAP|
 					CIFS_UNIX_POSIX_PATHNAMES_CAP|
@@ -2745,6 +2748,7 @@ cBytesSector=%u, cUnitTotal=%u, cUnitAvail=%d\n", (unsigned int)bsize, (unsigned
 					CIFS_UNIX_EXTATTR_CAP|
 					CIFS_UNIX_POSIX_PATH_OPERATIONS_CAP|
 					CIFS_UNIX_LARGE_READ_CAP|
+					CIFS_UNIX_TRANSPORT_ENCRYPTION_CAP|
 					(large_write ?
 					CIFS_UNIX_LARGE_WRITE_CAP : 0))));
 			break;


-- 
Samba Shared Repository


More information about the samba-cvs mailing list